@@ -15,8 +15,13 @@
 # or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 # for more details.
 
+import sys
+python3 = sys.version_info[0] >= 3
+
 import os
 import urllib
+if python3:
+    import urllib.parse
 import socket
 import tempfile
 
@@ -30,11 +35,13 @@ appname = 'ownCloud'
 
 print("Initializing "+appname+"-client-nautilus extension")
 
-
 def get_local_path(url):
     if url[0:7] == 'file://':
         url = url[7:]
-    return urllib.unquote(url)
+    if python3:
+        return urllib.parse.unquote(url)
+    else:
+        return urllib.unquote(url).decode('utf-8')
 
 def get_runtime_dir():
     """Returns the value of $XDG_RUNTIME_DIR, a directory path.
@@ -56,7 +63,7 @@ class SocketConnect(GObject.GObject):
         self._watch_id = 0
         self._sock = None
         self._listeners = [self._update_registered_paths]
-        self._remainder = ''
+        self._remainder = ''.encode('utf-8')
         self.nautilusVFSFile_table = {}  # not needed in this object actually but shared 
                                          # all over the other objects.
 
@@ -74,7 +81,7 @@ class SocketConnect(GObject.GObject):
         # print("Server command: " + cmd)
         if self.connected:
             try:
-                self._sock.send(cmd)
+                self._sock.send(cmd.encode('utf-8'))
             except:
                 print("Sending failed.")
                 self.reconnect()
@@ -113,17 +120,17 @@ class SocketConnect(GObject.GObject):
         # Prepend the remaining data from last call
         if len(self._remainder) > 0:
             data = self._remainder + data
-            self._remainder = ''
+            self._remainder = ''.encode('utf-8')
 
         if len(data) > 0:
             # Remember the remainder for next round
-            lastNL = data.rfind('\n');
+            lastNL = data.rfind('\n'.encode('utf-8'));
             if lastNL > -1 and lastNL < len(data):
                 self._remainder = data[lastNL+1:]
                 data = data[:lastNL]
 
-            for l in data.split('\n'):
-                self._handle_server_response(l)
+            for l in data.split('\n'.encode('utf-8')):
+                self._handle_server_response(l.decode('utf-8'))
         else:
             return False
 
